import Taro, {Component} from '@tarojs/taro'
import { View, Image, Text, Swiper, SwiperItem, ScrollView, Button } from '@tarojs/components'
import { connect } from '@tarojs/redux'
import { setUserInfo } from '@/actions/user'
import NavBar from '@/components/NavBar'
import './index.scss'


@connect(({ user, nav }) => ({
  user, nav
}), (dispatch) => ({
  setUserInfo (data) {
    dispatch(setUserInfo(data || {}))
  },
}))
class Index extends Component {

  state = {
  }
  componentWillReceiveProps (nextProps) {
    console.log(this.props, nextProps)
  }

  componentWillUnmount () { }
  componentDidMount() {
    this.handleLocation();
  }
  componentDidShow () { }

  componentDidHide () { }

  // 获取地址授权
  handleLocation() {
    // 可以通过 wx.getSetting 先查询一下用户是否授权了 "scope.record" 这个 scope
    Taro.getSetting({
      success:function(res){
        if (!res.authSetting['scope.userLocation']) {
          console.log("-------------不满足scope.userLocation权限----------");
          //申请授权
          Taro.authorize({
            scope: 'scope.userLocation',
            success() {},
            fail () {
              Taro.showModal({
                title: '是否授权当前位置',
                content: '需要获取您的地理位置，请确认授权，否则地图功能将无法使用',
                success: function (tip) {
                  if (tip.confirm) {
                      Taro.openSetting({
                        success: function (data) {
                          if (data.authSetting["scope.userLocation"] === true) {
                            Taro.showToast({
                              title: '授权成功',
                              icon: 'success',
                              duration: 1000
                            })
                          } else {
                            Taro.showToast({
                              title: '授权失败',
                              icon: 'success',
                              duration: 1000
                            })
                          }
                        }
                      })
                  }
                }
              })
            }
          })
        }
      }
    })
  }
  // 手动选择地址
  selectCity(){
    const {setUserInfo} = this.props
    // 可以通过 wx.getSetting 先查询一下用户是否授权了 "scope.record" 这个 scope
    Taro.chooseLocation({
      success (res) {
        setUserInfo(res)
      },
      fail (res) {
        console.log(res)
      }
    })
  }
  // 跳转到门店详情
  jumpDetail = () => {
    Taro.navigateTo({
      url: '/pages/storeDetail/index'
    })
  }
  //滚动页面触发
  onScroll = (e) => {
    console.log(e)
    if (e.currentTarget.scrollTop > 275) {
      console.log('出现搜索框')
    } else {
      console.log('隐藏搜索框')
    }
  }
  render () {
    const {nav} = this.props
    const titleTop = (nav.globalData.navHeight - nav.globalData.navTop - 17) / 2 + nav.globalData.navTop
    const user = this.props.user;
    console.log('user', user)
    return (
      <View>
        <NavBar pageName='首页' bgColor='#fff'>
          <View
            style={`left:${nav.globalData.navRight}px;top:${titleTop}px;background-color:rgba(255,255,255,.6)`}
            className='city'
            onClick={this.selectCity}
          >
            <Image className='loc-icon' src='http://hh-oss-picture.miyapay.com/box/8dcd356a4ae1ff0c2c0ac9fd69733ab8.png' />
          </View>
        </NavBar>
        <ScrollView
          style="height: 508px"
          className='scrollview'
          scrollY
          onScroll={this.onScroll}
        >
        <Swiper
          className='swpier-view'
          indicatorColor='#999'
          indicatorActiveColor='#333'
          circular
          indicatorDots
          autoplay
        >
          <SwiperItem>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
          </SwiperItem>
          <SwiperItem>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
          </SwiperItem>
          <SwiperItem>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
          </SwiperItem>
        </Swiper>
        <View className='sub-nav'>
          <View className='content'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <Text>领券</Text>
          </View>
          <View className='content'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <Text>券包</Text>
          </View>
        </View>
        <View className='sub-title'>
          <Text>领券中心</Text>
          <Text>查看全部</Text>
        </View>
        <View className='store-list-title' id='store'>
          <Text>附近门店</Text>
        </View>
        <View>
          <View className='list-view' onClick={this.jumpDetail}>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <View className='text-cont'>
              <Text>米雅遍历（北京店）</Text>
              <Text>营业时间 10:00 - 18:00</Text>
            </View>
            <View className='distance'>
              <Text>200m</Text>
            </View>
          </View>
          <View className='list-view' onClick={this.jumpDetail}>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <View className='text-cont'>
              <Text>米雅遍历（北京店）</Text>
              <Text>营业时间 10:00 - 18:00</Text>
            </View>
            <View className='distance'>
              <Text>200m</Text>
            </View>
          </View>
          <View className='list-view'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <View className='text-cont'>
              <Text>米雅遍历（北京店）</Text>
              <Text>营业时间 10:00 - 18:00</Text>
            </View>
            <View className='distance'>
              <Text>200m</Text>
            </View>
          </View>
          <View className='list-view'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <View className='text-cont'>
              <Text>米雅遍历（北京店）</Text>
              <Text>营业时间 10:00 - 18:00</Text>
            </View>
            <View className='distance'>
              <Text>200m</Text>
            </View>
          </View>
          <View className='list-view'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <View className='text-cont'>
              <Text>米雅遍历（北京店）</Text>
              <Text>营业时间 10:00 - 18:00</Text>
            </View>
            <View className='distance'>
              <Text>200m</Text>
            </View>
          </View>
          <View className='list-view'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <View className='text-cont'>
              <Text>米雅遍历（北京店）</Text>
              <Text>营业时间 10:00 - 18:00</Text>
            </View>
            <View className='distance'>
              <Text>200m</Text>
            </View>
          </View>
        </View>
        </ScrollView>
      </View>
    )
  }
}

export default Index
